@@ -1,4 +1,3 @@
-#include <iostream>
 #include <QtCore>
 #include <QDebug>
 #include <QMessageBox>
@@ -22,19 +21,22 @@
 #include "importexport.h"
 #include "plot.h"
 #include "searchdialog.h"
+#include "propertiesdialog.h"
 #include "listdialog.h"
 #include "system.h"
 #include "optimizer.h"
+#include "scaddialog.h"
 #include "undocommands.h"
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow),
-    projectSaved(false),
+    projectSaved(true),
     isModifying(false),
     spkDialog(nullptr),
     fileDialog(nullptr),
     searchDialog(nullptr),
+    propertiesDialog(nullptr),
     listDialog(nullptr),
     bandpassDialog(nullptr),
     currentSpeakerNumber(0),
@@ -79,6 +81,9 @@ MainWindow::MainWindow(QWidget *parent) :
     setMinimumWidth(800);
     ui->menuBar->setMinimumWidth(800);
 
+    ui->mainToolBar->setFloatable(false);
+    ui->mainToolBar->setMovable(false);
+
     /* insert QChartView plotters in ui */
     QHBoxLayout *ly1 = new QHBoxLayout(ui->sealedVolumePlotWidget);
     sealedPlot = new Plot(tr("Sealed volume frequency response"), ui->sealedVolumePlotWidget);
@@ -115,10 +120,8 @@ MainWindow::MainWindow(QWidget *parent) :
     this->ui->actionRedo->setEnabled(false);
 
     /* restore last saved project... */
-    if (loadFile(ImportExport::getSavePath()))
-        projectSaved = true;
-    else {
-        projectSaved = false;
+    if (!loadFile(ImportExport::getSavePath())) {
+        /* on error, set default values */
         currentSpeakerNumber = 1;
         currentTabIndex = 0;
     }
@@ -171,7 +174,7 @@ MainWindow::~MainWindow()
 void MainWindow::onProjectSave()
 {
 
-    if(ImportExport::saveProject(currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, currentSpeakerNumber, currentTabIndex)) {
+    if(ImportExport::saveProject(projectProperties, currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, currentSpeakerNumber, currentTabIndex)) {
         projectSaved = true;
 
 #if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
@@ -199,7 +202,7 @@ void MainWindow::onProjectExport()
         fileName += ".qsp";
 
     QFile file(fileName);
-    if(ImportExport::exportProject(file, currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, currentSpeakerNumber, currentTabIndex)) {
+    if(ImportExport::exportProject(file, projectProperties, currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, currentSpeakerNumber, currentTabIndex)) {
         setRecentFile(fileName, true);
     }
 }
@@ -209,7 +212,7 @@ void MainWindow::onProjectImport()
     if (!projectSaved) {
         QMessageBox::StandardButton pressed =
                 QMessageBox::question(this, tr("Project not saved"),
-                                      tr("The current project has not been saved. Continue anyway?"),
+                                      tr("Current project has not been saved. Continue anyway?"),
                                       QMessageBox::Yes|QMessageBox::No);
         if (pressed == QMessageBox::No)
             return;
@@ -229,6 +232,15 @@ void MainWindow::onProjectImport()
 
 void MainWindow::onOpenRecentActionTriggered()
 {
+    if (!projectSaved) {
+        QMessageBox::StandardButton pressed =
+                QMessageBox::question(this, tr("Project not saved"),
+                                      tr("Current project has not been saved. Continue anyway?"),
+                                      QMessageBox::Yes|QMessageBox::No);
+        if (pressed == QMessageBox::No)
+            return;
+    }
+
     QAction *action = qobject_cast<QAction *>(sender());
     if (action) {
         if (!loadFile(action->data().toString())) {
@@ -286,7 +298,7 @@ bool MainWindow::loadFile(const QString& fileName)
     unlinkTabs();
 
     QFile file(fileName);
-    if (!ImportExport::importProject(currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, &currentSpeakerNumber, &currentTabIndex, file)) {
+    if (!ImportExport::importProject(projectProperties, currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, &currentSpeakerNumber, &currentTabIndex, file)) {
         setRecentFile(fileName, false);
 
         linkInternals();
@@ -308,8 +320,6 @@ bool MainWindow::loadFile(const QString& fileName)
     ImportExport::setSavePath(fileName);
     setWindowFilePath(ImportExport::getSavePath());
 
-    ui->tabWidget->setCurrentIndex(currentTabIndex);
-
     syncUiFromCurrentSpeaker(currentSpeaker);
     syncUiFromCurrentSealedBox(currentSealedBox);
     syncUiFromCurrentPortedBox(currentPortedBox);
@@ -318,9 +328,14 @@ bool MainWindow::loadFile(const QString& fileName)
     linkInternals();
     linkTabs();
 
+    ui->tabWidget->setCurrentIndex(currentTabIndex);
+
+    /*
     if (notInDbSpeaker)
         onSpeakerModify();
+    */
 
+    projectSaved = true;
     return true;
 }
 
@@ -409,6 +424,8 @@ void MainWindow::syncUiFromCurrentSpeaker(const Speaker& spk)
     ui->vcValueLabel->setNum(currentSpeaker.getVc());
 
     linkTabs();
+
+    projectSaved = false;
 }
 
 void MainWindow::syncUiFromCurrentSealedBox(const SealedBox& box)
@@ -424,6 +441,8 @@ void MainWindow::syncUiFromCurrentSealedBox(const SealedBox& box)
     }
     sealedPlot->draw3dbVLine();
     linkTabs();
+
+    projectSaved = false;
 }
 
 void MainWindow::syncUiFromCurrentPortedBox(const PortedBox& box)
@@ -450,6 +469,8 @@ void MainWindow::syncUiFromCurrentPortedBox(const PortedBox& box)
     }
     portedPlot->draw3dbVLine();
     linkTabs();
+
+    projectSaved = false;
 }
 
 void MainWindow::syncUiFromCurrentBandPassBox(const BandPassBox& box)
@@ -477,6 +498,8 @@ void MainWindow::syncUiFromCurrentBandPassBox(const BandPassBox& box)
     }
     bandpassPlot->draw3dbVLine();
     linkTabs();
+
+    projectSaved = false;
 }
 
 void MainWindow::setCurrentSpeaker(const Speaker &spk)
@@ -496,29 +519,49 @@ bool MainWindow::print(QPrinter *printer)
         return false;
 
     QRect page = printer->pageLayout().paintRectPixels(printer->resolution());
+    QMargins margins = printer->pageLayout().marginsPixels(printer->resolution());
+    qreal realwidth = page.width() - 2 * margins.left();
 
-    qreal step = page.height() / 4.0;
+    qreal textheight = painter.fontMetrics().height();
+    qreal step = 0;
+
+    QFont font;
+    font.setBold(true);
+    painter.setFont(font);
+
+    QPen pen;
+    pen.setCosmetic(true);
+    painter.setPen(pen);
+
+    QTextOption option(Qt::AlignHCenter);
+    painter.drawText(QRectF(page.left(), page.top(), realwidth, page.height()), projectProperties.title, option);
+    step += textheight;
 
     if (ui->tabWidget->currentWidget() == ui->sealedTab) {
         System s(currentSpeaker, &currentSealedBox, currentSpeakerNumber);
-        s.render(&painter, QRectF(page.left(), page.top(), page.width(), step));
-        //sealedPlot->setUseOpenGL(false);
-        sealedPlot->render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height() - step));
-        //sealedPlot->setUseOpenGL(true);
+        s.render(&painter, QRectF(page.left(), page.top() + step, realwidth, page.height() / 4.));
+        step += page.height() / 4.;
+        sealedPlot->render(&painter, QRectF(page.left(), page.top() + step, realwidth, page.height() / 2.));
+        step += page.height() / 2.;
     } else if (ui->tabWidget->currentWidget() == ui->portedTab) {
         System s(currentSpeaker, &currentPortedBox, currentSpeakerNumber);
-        s.render(&painter, QRectF(page.left(), page.top(), page.width(), step));
-        //portedPlot->setUseOpenGL(false);
-        portedPlot->render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height() - step));
-        //portedPlot->setUseOpenGL(true);
+        s.render(&painter, QRectF(page.left(), page.top() + step, realwidth, page.height() / 4.));
+        step += page.height() / 4.;
+        portedPlot->render(&painter, QRectF(page.left(), page.top() + step, realwidth, page.height() / 2.));
+        step += page.height() / 2.;
     } else {
         System s(currentSpeaker, &currentBandPassBox, currentSpeakerNumber);
-        s.render(&painter, QRectF(page.left(), page.top(), page.width(), step));
-        //bandpassPlot->setUseOpenGL(false);
-        bandpassPlot->render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height() - step));
-        //bandpassPlot->setUseOpenGL(true);
+        s.render(&painter, QRectF(page.left(), page.top() + step, realwidth, page.height() / 4.));
+        step += page.height() / 4.;
+        bandpassPlot->render(&painter, QRectF(page.left(), page.top() + step, realwidth, page.height() / 2.));
+        step += page.height() / 2.;
     }
 
+    font.setBold(false);
+    painter.setFont(font);
+
+    painter.drawText(QRectF(page.left(), page.top() + step, page.width(), page.height() - step), projectProperties.note);
+
     painter.end();
     return true;
 }
@@ -570,7 +613,7 @@ void MainWindow::onCurvePlot()
 {
     QString home = getHome();
     QString box = ui->tabWidget->currentWidget()->objectName().replace("Tab", "Box");
-    QString f = QString("QSpeakers %1 %2").arg(currentSpeaker.getModel()).arg(box);
+    QString f = QString("QSpeakers %1 %2 %3").arg(currentSpeaker.getVendor()).arg(currentSpeaker.getModel()).arg(box);
     f.replace(' ', '_');
     QString fileName = QFileDialog::getSaveFileName(this, tr("Export for Gnuplot"), home + QDir::separator() + f + ".dat", tr("Gnuplot data (*.dat)"));
 
@@ -583,9 +626,19 @@ void MainWindow::onCurvePlot()
 
 void MainWindow::on3DScadExport()
 {
+    bool ok = false;
+    QList<qreal> vals = ScadDialog::getValues(2, this, &ok);
+    if (!ok)
+        return;
+
+    Q_ASSERT(vals.size() == 2);
+
+    qreal margin = vals.at(0); /* loudspeaker margin */
+    qreal thick = vals.at(1); /* wood thick */
+
     QString home = getHome();
     QString box = ui->tabWidget->currentWidget()->objectName().replace("Tab", "Box");
-    QString f = QString("QSpeakers %1 %2 3D").arg(currentSpeaker.getModel()).arg(box);
+    QString f = QString("QSpeakers %1 %2 %3 3D").arg(currentSpeaker.getVendor()).arg(currentSpeaker.getModel()).arg(box);
     f.replace(' ', '_');
     QString fileName = QFileDialog::getSaveFileName(this, tr("Export for 3D OpenSCAD"), home + QDir::separator() + f + ".scad", tr("OpenSCAD script (*.scad)"));
 
@@ -593,14 +646,25 @@ void MainWindow::on3DScadExport()
     if (fileName.isEmpty())
         return;
 
-    exportScad3D(fileName, currentTabIndex);
+    exportScad3D(fileName, currentTabIndex, margin, thick);
 }
 
 void MainWindow::on2DScadExport()
 {
+    bool ok = false;
+    QList<qreal> vals = ScadDialog::getValues(3, this, &ok);
+    if (!ok)
+        return;
+
+    Q_ASSERT(vals.size() == 3);
+
+    qreal margin = vals.at(0); /* loudspeaker margin */
+    qreal thick = vals.at(1); /* wood thick */
+    qreal saw = vals.at(2); /* saw thick */
+
    QString home = getHome();
    QString box = ui->tabWidget->currentWidget()->objectName().replace("Tab", "Box");
-   QString f = QString("QSpeakers %1 %2 2D").arg(currentSpeaker.getModel()).arg(box);
+   QString f = QString("QSpeakers %1 %2 %3 2D").arg(currentSpeaker.getVendor()).arg(currentSpeaker.getModel()).arg(box);
    f.replace(' ', '_');
    QString fileName = QFileDialog::getSaveFileName(this, tr("Export for 2D OpenSCAD"), home + QDir::separator() + f + ".scad", tr("OpenSCAD script (*.scad)"));
 
@@ -608,14 +672,14 @@ void MainWindow::on2DScadExport()
     if (fileName.isEmpty())
         return;
 
-   exportScad2D(fileName, currentTabIndex);
+   exportScad2D(fileName, currentTabIndex, margin, thick, saw);
 }
 
 void MainWindow::exportPlot(const QString& outfileName, int tabindex)
 {
     QFile file(outfileName);
     QString f("# QSpeakers plot: ");
-    f += currentSpeaker.getModel() + "\n";
+    f += currentSpeaker.getVendor() + " " + currentSpeaker.getModel() + "\n";
     f += "# freq., dB.\n";
 
     QLineSeries* series;
@@ -651,23 +715,19 @@ void MainWindow::exportPlot(const QString& outfileName, int tabindex)
     file.close();
 }
 
-/* FIXME: should be taken from a popup before to export */
-#define MARGIN 50 /* mm */
-#define WOODTHICK 20 /* mm */
-#define SAWTHICK 1 /* mm */
-
-void MainWindow::exportScad(const QString& scad, const QString &outfileName, int tabindex)
+void MainWindow::exportScad(const QString& scad, const QString &outfileName, int tabindex, qreal margin, qreal thick, qreal saw)
 {
     QFile templ(scad);
     templ.open(QIODevice::ReadOnly);
     QString s = templ.readAll();
 
+    s.replace("__VENDOR__", currentSpeaker.getVendor());
     s.replace("__MODEL__", currentSpeaker.getModel());
     s.replace("__NUMBER__", QString::number(currentSpeakerNumber));
-    s.replace("__MARGIN__", QString::number(MARGIN));
+    s.replace("__MARGIN__", QString::number(margin));
     s.replace("__DIAMETER__", QString::number(currentSpeaker.getDia() * 1000)); /* mm */
-    s.replace("__WOODTHICK__", QString::number(WOODTHICK));
-    s.replace("__SAWTHICK__", QString::number(SAWTHICK));
+    s.replace("__WOODTHICK__", QString::number(thick));
+    s.replace("__SAWTHICK__", QString::number(saw));
     if (tabindex == 0) {
         s.replace("__SEALEDBOXVOLUME__", QString::number(currentSealedBox.getVolume()));
     } else if (tabindex == 1) {
@@ -711,7 +771,41 @@ void MainWindow::exportScad(const QString& scad, const QString &outfileName, int
     f.close();
 }
 
-void MainWindow::exportScad3D(const QString &outfileName, int tabindex)
+void MainWindow::onProjectProperties()
+{
+    propertiesDialog = new PropertiesDialog(this);
+    propertiesDialog->setTitle(projectProperties.title);
+    propertiesDialog->setNote(projectProperties.note);
+    connect(propertiesDialog, &QDialog::accepted, this, &MainWindow::onPropertiesAccepted);
+    connect(propertiesDialog,&QDialog::rejected, this, &MainWindow::onPropertiesRejected);
+    propertiesDialog->show();
+}
+
+void MainWindow::onPropertiesRejected()
+{
+    disconnect(propertiesDialog, &QDialog::accepted, this, &MainWindow::onPropertiesAccepted);
+    disconnect(propertiesDialog, &QDialog::rejected, this, &MainWindow::onPropertiesRejected);
+    propertiesDialog->close();
+    propertiesDialog->deleteLater();
+    propertiesDialog = nullptr;
+}
+
+void MainWindow::onPropertiesAccepted()
+{
+    if (projectProperties.title != propertiesDialog->getTitle() || projectProperties.note != propertiesDialog->getNote())
+        projectSaved = false;
+
+    projectProperties.title = propertiesDialog->getTitle();
+    projectProperties.note = propertiesDialog->getNote();
+
+    disconnect(propertiesDialog, &QDialog::accepted, this, &MainWindow::onPropertiesAccepted);
+    disconnect(propertiesDialog, &QDialog::rejected, this, &MainWindow::onPropertiesRejected);
+    propertiesDialog->close();
+    propertiesDialog->deleteLater();
+    propertiesDialog = nullptr;
+}
+
+void MainWindow::exportScad3D(const QString &outfileName, int tabindex, qreal margin, qreal thick)
 {
     QFile file(outfileName);
     QString scad;
@@ -751,11 +845,11 @@ void MainWindow::exportScad3D(const QString &outfileName, int tabindex)
         return;
     }
 
-    exportScad(scad, outfileName, tabindex);
+    exportScad(scad, outfileName, tabindex, margin, thick, 0);
 }
 
 
-void MainWindow::exportScad2D(const QString &outfileName, int tabindex)
+void MainWindow::exportScad2D(const QString &outfileName, int tabindex, qreal margin, qreal thick, qreal saw)
 {
     QFile file(outfileName);
     QString scad;
@@ -795,11 +889,12 @@ void MainWindow::exportScad2D(const QString &outfileName, int tabindex)
         return;
     }
 
-    exportScad(scad, outfileName, tabindex);
+    exportScad(scad, outfileName, tabindex, margin, thick, saw);
 }
 
 void MainWindow::linkMenus()
 {
+    connect(ui->actionProjectProperties, &QAction::triggered, this, &MainWindow::onProjectProperties);
     connect(ui->actionProjectSave, &QAction::triggered, this, &MainWindow::onProjectSave);
     connect(ui->actionProjectQuit, &QAction::triggered, this, &MainWindow::onProjectQuit);
     connect(ui->actionSpeakerNew, &QAction::triggered, this, &MainWindow::onSpeakerNew);
@@ -835,8 +930,13 @@ void MainWindow::linkTabs()
     connect(ui->tabWidget, &QTabWidget::currentChanged, this, &MainWindow::onCurrentTabChanged);
 
     /* spk combos action */
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
     connect(ui->vendorComboBox, &QComboBox::textActivated, this, &MainWindow::onVendorChanged);
     connect(ui->modelComboBox, &QComboBox::textActivated, this, &MainWindow::onModelChanged);
+#else
+    connect(ui->vendorComboBox, QOverload<const QString&>::of(&QComboBox::activated), this, &MainWindow::onVendorChanged);
+    connect(ui->modelComboBox, QOverload<const QString&>::of(&QComboBox::activated), this, &MainWindow::onModelChanged);
+#endif
 
     /* drivers number spin action */
     connect(ui->numberSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onNumberSpinChanged);
@@ -872,6 +972,7 @@ void MainWindow::linkInternals()
 
 void MainWindow::unlinkMenus()
 {
+    disconnect(ui->actionProjectProperties, &QAction::triggered, this, &MainWindow::onProjectProperties);
     disconnect(ui->actionProjectSave, &QAction::triggered, this, &MainWindow::onProjectSave);
     disconnect(ui->actionProjectQuit, &QAction::triggered, this, &MainWindow::onProjectQuit);
     disconnect(ui->actionSpeakerNew, &QAction::triggered, this, &MainWindow::onSpeakerNew);
@@ -900,8 +1001,13 @@ void MainWindow::unlinkTabs()
     disconnect(ui->tabWidget, &QTabWidget::currentChanged, this, &MainWindow::onCurrentTabChanged);
 
     /* spk combos action */
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
     disconnect(ui->vendorComboBox, &QComboBox::textActivated, this, &MainWindow::onVendorChanged);
     disconnect(ui->modelComboBox, &QComboBox::textActivated, this, &MainWindow::onModelChanged);
+#else
+    disconnect(ui->vendorComboBox, QOverload<const QString&>::of(&QComboBox::activated), this, &MainWindow::onVendorChanged);
+    disconnect(ui->modelComboBox, QOverload<const QString&>::of(&QComboBox::activated), this, &MainWindow::onModelChanged);
+#endif
 
     disconnect(ui->numberSpinBox, QOverload<int>::of(&QSpinBox::valueChanged), this, &MainWindow::onNumberSpinChanged);
 
@@ -1096,7 +1202,9 @@ void MainWindow::onProjectPrint()
 {
     QPrinter printer;
     printer.setCreator("QSpeakers");
-    printer.setDocName("qspeakers_project");
+    printer.setDocName("QSpeakers Project");
+    QString box = ui->tabWidget->currentWidget()->objectName().replace("Tab", "Box");
+    printer.setOutputFileName("QSpeakers_" + currentSpeaker.getVendor() + "_" + currentSpeaker.getModel() + "_" + box + ".pdf");
     printer.setPageOrientation(QPageLayout::Landscape);
     QPrintDialog dialog(&printer, this);
     if (dialog.exec() == QDialog::Accepted) {
@@ -1133,7 +1241,7 @@ void MainWindow::onAboutAbout()
                           "This program is free software, copyright (C) 2014 "
                           "Benoit Rouits <brouits@free.fr> and released under the "
                           "GNU General Public Lisence version 3. It is delivered "
-                          "as is in the hope it can be useful, but with no warranty at all.").arg(VERSION, REVISION));
+                          "as is in the hope it can be useful, but with NO WARRANTY at all.").arg(VERSION, REVISION));
 }
 
 void MainWindow::onSearchRequested(const QString& param, double min, double max)
@@ -1193,9 +1301,6 @@ void MainWindow::setActivateActions(QList<QAction*> actions, bool enable)
 
 void MainWindow::onCurrentTabChanged(int tab)
 {
-    if (tab == currentTabIndex)
-        return;
-
     this->commandStack->clear();
 
     QList<QAction*> alignments = ui->menuPorted_alignments->actions();
@@ -1250,7 +1355,6 @@ void MainWindow::changeSpeakerNumber(int number) {
         return;
     }
 
-    projectSaved = false;
     syncUiFromCurrentSealedBox(currentSealedBox);
     syncUiFromCurrentPortedBox(currentPortedBox);
     syncUiFromCurrentBandPassBox(currentBandPassBox);
@@ -1267,7 +1371,7 @@ void MainWindow::onVendorChanged(QString vendor)
 
         QMessageBox::StandardButton pressed =
                 QMessageBox::question(this, tr("Unsaved speaker"),
-                                      tr("This speaker is not present in the database. Would you like to insert it before to continue?"),
+                                      tr("Speaker driver %1 is not present in the database. Do you want to insert it before to continue?").arg(notInDbSpeaker->getModel()),
                                       QMessageBox::Yes|QMessageBox::No);
         if (pressed == QMessageBox::Yes) {
             SpeakerDb::insertOrReplace(notInDbSpeaker->getVendor(), notInDbSpeaker->getModel(), *notInDbSpeaker);
@@ -1324,7 +1428,7 @@ void MainWindow::onModelChanged(QString model)
 
         QMessageBox::StandardButton pressed =
                 QMessageBox::question(this, tr("Unsaved speaker"),
-                                      tr("This speaker is not present in the database. Would you like to insert it before to continue?"),
+                                      tr("Speaker driver %1 is not present in the database. Do you want to insert it before to continue?").arg(notInDbSpeaker->getModel()),
                                       QMessageBox::Yes|QMessageBox::No);
         if (pressed == QMessageBox::Yes) {
             SpeakerDb::insertOrReplace(notInDbSpeaker->getVendor(), notInDbSpeaker->getModel(), *notInDbSpeaker);
@@ -1383,7 +1487,6 @@ void MainWindow::onCurrentSpeakerChanged(const Speaker &spk)
         return;
     }
 
-    projectSaved = false;
     syncUiFromCurrentSealedBox(currentSealedBox);
     syncUiFromCurrentPortedBox(currentPortedBox);
     syncUiFromCurrentBandPassBox(currentBandPassBox);
@@ -1406,7 +1509,6 @@ void MainWindow::onCurrentSealedBoxChanged(const SealedBox &box)
     if (!currentSpeaker.isValid())
         return;
 
-    projectSaved = false;
     syncUiFromCurrentSealedBox(box);
 }
 
@@ -1461,6 +1563,7 @@ void MainWindow::changePortedPortDiam(double val)
     currentPortedBox.setPortDiam(val);
     currentPortedBox.updateSlots();
     currentPortedBox.updatePortsLength();
+
     syncUiFromCurrentPortedBox(currentPortedBox);
 }
 
@@ -1489,6 +1592,7 @@ void MainWindow::onPortedSlotWidthDoubleSpinChanged(double val)
 void MainWindow::changePortedSlotWidth(double val)
 {
     currentPortedBox.setSlotWidth(val);
+
     syncUiFromCurrentPortedBox(currentPortedBox);
 }
 
@@ -1497,7 +1601,6 @@ void MainWindow::onCurrentPortedBoxChanged(const PortedBox &box)
     if (!currentSpeaker.isValid())
         return;
 
-    projectSaved = false;
     syncUiFromCurrentPortedBox(box);
 }
 
@@ -1598,6 +1701,6 @@ void MainWindow::onCurrentBandPassBoxChanged(const BandPassBox &box)
     if (!currentSpeaker.isValid())
         return;
 
-    projectSaved = false;
     syncUiFromCurrentBandPassBox(box);
 }
+// vim:sw=4:ts=4:et
