@@ -1,17 +1,18 @@
 #include <QLocale>
 #include <QDebug>
 
-#include <math.h>
+#include <cmath>
 
 #include "portedbox.h"
 
 PortedBox::PortedBox(double volume, double resfreq, unsigned int portnum, double portdiam, double portlen) :
     box(volume)
 {
-    resFreq = resfreq;
+    setResFreq(resfreq);
     portNum = portnum;
-    portDiam = portdiam;
-    portLen = portlen;
+    setPortDiam(portdiam);
+    setPortLen(portlen);
+    slotActivated = false;
 }
 
 void PortedBox::setBoxVolume(double vol)
@@ -26,22 +27,27 @@ void PortedBox::setPortNum(unsigned int value)
 
 void PortedBox::setPortLen(double len)
 {
-    portLen = len;
+    portLen = double ((int)(len * 100) / 100.0);
 }
 
 void PortedBox::setPortDiam(double diam)
 {
-    portDiam = diam;
+    portDiam = double ((int)(diam * 100) / 100.0);
 }
 
 void PortedBox::setSlotWidth(double width)
 {
-    slotWidth = width;
+    slotWidth = double ((int)(width * 100) / 100.0);
 }
 
 void PortedBox::setResFreq(double value)
 {
-    resFreq = value;
+    resFreq = double ((int)(value * 100) / 100.0);
+}
+
+void PortedBox::setSlotPortActivated(bool enable)
+{
+    slotActivated = enable;
 }
 
 double PortedBox::getBoxVolume() const
@@ -56,7 +62,16 @@ unsigned int PortedBox::getPortNum() const
 
 double PortedBox::getPortLen() const
 {
-    return portLen;
+    if (!slotActivated)
+        return portLen;
+
+    double x = getSlotWidth() / getSlotHeight();
+    if (x < 1) {
+        x = getSlotHeight() / getSlotWidth();
+    }
+
+    /* estimated from https://sites.google.com/site/francisaudio69/ */
+    return double ((int)((1.1 - log10(x + 1.1) * 0.35) * portLen * 100) / 100.0);
 }
 
 double PortedBox::getPortDiam() const
@@ -64,6 +79,11 @@ double PortedBox::getPortDiam() const
     return portDiam;
 }
 
+bool PortedBox::getSlotPortActivated() const
+{
+    return slotActivated;
+}
+
 double PortedBox::getSlotWidth() const
 {
     return slotWidth;
@@ -72,7 +92,7 @@ double PortedBox::getSlotWidth() const
 double PortedBox::getSlotHeight() const
 {
     /* width is manual, height is computed from eq. diam. */
-    return (PI * pow(portDiam, 2.0)) / (4.0 * slotWidth);
+    return double ((int)((M_PI * pow(portDiam, 2.0)) / (4.0 * slotWidth) * 100) / 100.0);
 }
 
 double PortedBox::getResFreq() const
@@ -94,11 +114,11 @@ void PortedBox::updateSlots()
 {
     /* compute square slot */
     double diam = getPortDiam();
-    double s = sqrt(PI * pow(diam, 2.0) / 4.0);
+    double s = sqrt(M_PI * pow(diam, 2.0) / 4.0);
 
     /* consider "width" over "height" and reset if too small */
     if (slotWidth == 0.0)
-        slotWidth = s;
+        slotWidth = double ((int)(s * 100) / 100.0);
 }
 
 void PortedBox::updatePortsLength()
@@ -129,6 +149,7 @@ QDomElement PortedBox::toDomElement(QDomDocument& doc) const
     p.setAttribute("len", c.toString(portLen));
     p.setAttribute("diam", c.toString(portDiam));
     p.setAttribute("width", c.toString(slotWidth));
+    p.setAttribute("slot", c.toString(slotActivated ? 1 : 0));
 
     e.appendChild(p);
 
@@ -156,32 +177,43 @@ void PortedBox::fromDomElement(const QDomElement &e)
     portLen = c.toDouble(p.attribute("len"));
     portDiam = c.toDouble(p.attribute("diam"));
     slotWidth = c.toDouble(p.attribute("width"));
+    slotActivated = c.toUInt(p.attribute("slot"));
 }
 
 void PortedBox::render(QPainter *painter, const QRectF &area) const
-{    
-    if (!painter)
-        return;
+{
+    QFont orig = painter->font();
 
-#define PORTED_PARAMS 6
+#define PORTED_PARAMS 5
 
     QString params[PORTED_PARAMS];
-    qreal tab = area.left();
+    qreal tab = area.left() + BOX_RENDER_MARGINS;
+    qreal realwidth = area.width() - 2 * BOX_RENDER_MARGINS;
 
-    painter->drawRoundRect(area.toRect(), 5, 5);
+    painter->drawRoundedRect(area.toRect(), 5, 5);
 
-    params[0] = QObject::tr("Vol. %1 L").arg(getBoxVolume());
-    params[1] = QObject::tr("Port Diam. %1 cm").arg(getPortDiam());
-    params[2] = QObject::tr("[Slot %1x%2 cm]").arg(QString::number(getSlotWidth(), 'f', 2), QString::number(getSlotHeight(), 'f', 2));
-    params[3] = QObject::tr("Port Len. %1 cm").arg(QString::number(getPortLen(), 'f', 2));
-    params[4] = QObject::tr("Port Num. %1").arg(QString::number(getPortNum()));
-    params[5] = QObject::tr("Fb %1 Hz").arg(QString::number(getResFreq()));
+    params[0] = QObject::tr("Volume: %1 L").arg(QString::number(getBoxVolume(), 'f', 2));
+    if (!slotActivated) {
+        params[1] = QObject::tr("Port Diameter: %1 cm").arg(QString::number(getPortDiam(), 'f', 1));
+    } else {
+        params[1] = QObject::tr("Slot port: %1 x %2 cm").arg(QString::number(getSlotWidth(), 'f', 1), QString::number(getSlotHeight(), 'f', 1));
+    }
+    params[2] = QObject::tr("Port Length: %1 cm").arg(QString::number(getPortLen(), 'f', 1));
+    params[3] = QObject::tr("Port #: %1").arg(QString::number(getPortNum()));
+    params[4] = QObject::tr("Fb: %1 Hz").arg(QString::number(getResFreq()));
+
+    QFont font;
+    font.setBold(false);
+    painter->setFont(font);
 
     for (int i = 0; i < PORTED_PARAMS; i++) {
         QString text = params[i];
-        QRectF where(tab, area.top(), area.width() / PORTED_PARAMS, area.height());
         QTextOption option(Qt::AlignVCenter|Qt::AlignLeft);
+        qreal textwidth = painter->boundingRect(QRect(0, 0, realwidth, 0), text, option).width() + BOX_RENDER_MARGINS;
+        QRectF where(tab, area.top(), qMax(realwidth / PORTED_PARAMS, textwidth), area.height());
         painter->drawText(where, text, option);
-        tab += area.width() / PORTED_PARAMS;
+        tab += where.width();
     }
+
+    painter->setFont(orig);
 }
